Command Line Interface
======================

SOSSE provides a ``sosse-admin`` command that is based on the `Django management command <https://docs.djangoproject.com/en/3.2/ref/django-admin/>`_.
It can be called with ``sosse-amdin help``, to list all commands available, and ``sosse-admin help <command>`` to get help a specific command. The help
for SOSSE specific commands is also provided below:

.. include:: cli_generated.rst
